
import shutil, os
from send2trash import send2trash as send2trash_original


def send2trash(path):
	try:
		send2trash_original(path)
	except:
		if os.path.isdir(path):
			shutil.rmtree(path)
		else:
			os.remove(path)




UUID4_FLAG           = '__UUID4__'
CREATED_ON_FLAG      = '__CREATED-ON__'
UPDATED_ON_FLAG      = '__UPDATED-ON__'
SOFTWARE_REF_FLAG    = '__SOFTWARE__'
PARENT_REF_FLAG      = '__PARENT-REF__'
EXTERNAL_REF_FLAG    = '__EXTERNAL-REF__'
EXTERNAL_FILE_FLAG   = '__EXTERNAL-FILE__'
EXTERNAL_URL_FLAG    = '__EXTERNAL-URL__'
DEFINITION_TEXT_FLAG = '__DEF-TEXT__'
DEFINITION_URL_FLAG  = '__DEF-URL__'

HAS_HEADER_FLAG      = '__HAS-HEADER__'


#!/usr/bin/python
# -*- coding: utf-8 -*-

from setuptools import setup, find_packages
import re

version = None
with open('sca/__init__.py', 'r') as fd:
	version = re.search(r'^__version__\s*=\s*[\'"]([^\'"]*)[\'"]', fd.read(), re.MULTILINE).group(1)
if not version: raise RuntimeError('Cannot find version information')

setup(
	name='safe and collaborative architecture',
	version=version,
	description="""This library implements the safe & collaborative architecture.""",
	author=['Ricardo Ribeiro'],
	author_email='ricardojvr@gmail.com',
	url='https://bitbucket.org/fchampalimaud/safe-collaborative-architecture',
	include_package_data=True,
	packages=find_packages(exclude=['docs']),
)